R Package Dependencies

The following is a list of all of the R packages RStudio depends on in some way. None of these packages are necessary for the basic operation of RStudio; they all enable additional IDE functionality as noted in Features.

This information is also available in the IDE itself using the rstudioapi package as follows:

rstudioapi::getRStudioPackageDependencies()

Note that some of these packages may require a higher version of R than RStudio itself requires; consult the individual package’s documentation for more details.

Name Version Features
base64enc 0.1-3
checkmate 1.0
crayon 1.3.4
curl 4.2
DBI 0.8 Database Interface, RSQLite
devtools 1.11.1 R Unit Testing
digest 0.6 R Markdown
ellipsis 0.2.0.1
evaluate 0.13
fastmap 1.1.0
glue 1.3.0
haven 0.2.0 SPSS/SAS/Stata Import
highr 0.3
htmltools 0.3.6 R Markdown
htmlwidgets 1.2 Visual Profiling
httpuv 1.3.3
jsonlite 0.9.19 R Markdown, JSON Import
keyring 1.1.0 Secret Management
knitr 1.22 R Markdown
later 0.7.2
learnr 0.10.1 RStudio Tutorials
magrittr 1.5
markdown 0.7
mime 0.5
miniUI 0.1.1 Shiny Add-Ins
mongolite 0.8 Mongo DB Import
odbc 1.1.6 ODBC Connections
openssl 1.0.2
packrat 0.7.0 Packrat
plumber 1.0.0 Plumber R APIs
png 0.1-7
profvis 0.3.2 Visual Profiling
promises 1.0.1
pysparklyr 0.1.2 RStudio Databricks Connect Integration
r2d3 0.2.2 R2D3
R6 2.0
ragg 0.1.5 R Interface to AGG
rappdirs 0.3.0
Rcpp 0.11.5
readr 1.1.0 CSV Import
readxl 0.1.0 Excel Import
renv 0.9.3 renv
reticulate 1.20 Python/Reticulate
rJava 0.4-15
RJDBC 0.2-5 JDBC Import
rlang 0.2.2
rmarkdown 2.10 R Markdown
RODBC 1.3-12 ODBC Import
roxygen2 6.0.1 R Package Documentation
rprojroot 1.0
rsconnect 1.3.1 Publishing
RSQLite 2.1.0 RSQLite
rstan 2.15.1 Stan
rstudioapi 0.11 Shiny Add-Ins, ODBC Connections, RStudio Tutorials
shiny 1.2.0 Shiny
shinytest2 0.2.0 Shiny Tests
sourcetools 0.1.5
sparklyr 1.8.4 RStudio Databricks Connect Integration
stringi 0.3.0
stringr 1.2.0
styler 1.10.3 styler
testthat 2.0.0 R Unit Testing
tinytex 0.31 TinyTeX
withr 1.0.0
xfun 0.21
xml2 1.2.0 Theme Conversion, XML Import
xtable 1.7
yaml 2.1.19 R Markdown
Back to top